from datetime import datetime
from blog import db, login_manager
from flask_login import UserMixin
import bcrypt
from werkzeug.security import generate_password_hash, check_password_hash

class Post(db.Model):
  id = db.Column(db.Integer, primary_key=True)
  date = db.Column(db.DateTime, nullable=False, default=datetime.utcnow)
  title = db.Column(db.Text, nullable=False)
  content = db.Column(db.Text, nullable=False)
  author_id = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)

  def __repr__(self):
    return f"Post('{self.date}', '{self.title}', '{self.content}')"

class User(UserMixin,db.Model):
  id = db.Column(db.Integer, primary_key=True)
  username = db.Column(db.String(15), unique=True, nullable=False)
  password = db.Column(db.String(128))
  post = db.relationship('Post', backref='user', lazy=True)
  is_admin=db.Column(db.Boolean,nullable=False,default=False)
  email=db.Column(db.String(256), unique=True)
  
  def set_password(self,password):
    self.password = bcrypt.hashpw(password.encode('utf-8'), bcrypt.gensalt())

  def check_password(self,password):
    return bcrypt.checkpw(password.encode(), self.password.encode)

  def __repr__(self):
    return f"User('{self.username}')"

class Portfolio(db.Model):
  id = db.Column(db.Integer, primary_key=True)
  title = db.Column(db.String(255))
  description = db.Column(db.Text)
  date_completed = db.Column(db.Date)
  client = db.Column(db.String(255))
  technologies = db.Column(db.String(255))
  link = db.Column(db.String(255))



@login_manager.user_loader
def load_user(user_id):
  return User.query.get(int(user_id))
